===========================
 API Reference
===========================

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    kombu.connection
    kombu.simple
    kombu.messaging
    kombu.entity
    kombu.compat
    kombu.pidbox
    kombu.exceptions
    kombu.transport
    kombu.transport.pyamqplib
    kombu.transport.pypika
    kombu.transport.memory
    kombu.transport.pyredis
    kombu.transport.beanstalk
    kombu.transport.mongodb
    kombu.transport.pycouchdb
    kombu.transport.base
    kombu.transport.virtual
    kombu.transport.virtual.exchange
    kombu.transport.virtual.scheduling
    kombu.serialization
    kombu.compression
    kombu.abstract
    kombu.utils
    kombu.utils.functional
    kombu.utils.compat
    kombu.utils.finalize
